@@ -1,5 +1,5 @@
 CommunityProfile <-
-function(FUN, NorP, q.seq, ..., CheckArguments = TRUE) 
+function(FUN, NorP, q.seq = seq(0, 2, 0.1), ..., CheckArguments = TRUE) 
 {
   if (CheckArguments) {
     CheckentropartArguments()
