@@ -1,5 +1,5 @@
 bcShannon<-
-function(Ns, Correction="Best", CheckArguments = TRUE) 
+function(Ns, Correction = "Best", CheckArguments = TRUE) 
 {
   if (CheckArguments)
     CheckentropartArguments()
@@ -68,11 +68,28 @@ function(Ns, Correction="Best", CheckArguments = TRUE)
     }
     Part2 <- sapply(1:(Nrecords-1), function(r) 1/r*(1-A)^r) 
     ChaoWangJost <- sum(Ns/Nrecords*(digamma(Nrecords)-digamma(Ns)))
-    if (!is.na(Singletons)) {
+    if (!is.na(Singletons) & (A != 1)) {
       ChaoWangJost <- as.numeric(ChaoWangJost + Singletons/Nrecords*(1-A)^(1-Nrecords)*(-log(A)-sum(Part2)))
     }
     return(ChaoWangJost)  
-  } 
+  }
+  if (Correction == "ZhangHz") {
+    # Values of v
+    V <- 1:(Nrecords-1)
+    Ps <- Ns/Nrecords
+    # Weight part. Taken in log or goes to Inf for v > 1000; gamma cannot be used for large n, lgamma is preferred.
+    lnw_v <- ((V+1)*log(Nrecords)+lgamma(Nrecords-V)-lgamma(Nrecords+1)-log(V))
+    # p_V_Ps is an array, containing (1 - p_s - j/n) for each species (lines) and all j from 0 to n-2. Because array indexation starts from 1 in R, j is replaced by j-1.
+    p_V_Ps <- outer(Ps, V, function(Ps, j) 1 -Ps -(j-1)/Nrecords)
+    # Useful values are products from j=0 to v, so prepare cumulative products
+    p_V_Ps <- apply(p_V_Ps, 1, cumprod)
+    # Sum of products, weighted by p_s
+    S_s <- function(v) {
+      sum(Ps*p_V_Ps[v, 1:length(Ps)])
+    }
+    # Apply S_s to all values of v. Use logs or w_v goes to Inf.
+    return(sum(exp(lnw_v + log(sapply(V, S_s)))))
+  }
   warning("Correction was not recognized")
   return (NA)
 }
