@@ -1,7 +1,7 @@
 summary.DivPart <-
 function(object, ...) {
   
-  cat("Diversity partitioning of order", object$Order, "of MetaCommunity", object$MetaCommunity, fill=TRUE)
+  cat(object$Method, "diversity partitioning of order", object$Order, "of metaCommunity", object$MetaCommunity, fill=TRUE)
   if (!object$Biased)  
     cat(" with correction:", object$Correction)
   cat("\n")
@@ -10,6 +10,10 @@ function(object, ...) {
     cat("Phylogenetic or functional diversity was calculated according to the tree", object$Tree, "\n", fill=TRUE)
     cat("Diversity is", ifelse(object$Normalized, "", "not"), "normalized\n", fill=TRUE)
   }
+  if (!is.null(object$Z)) {
+    cat("Phylogenetic or functional entropy was calculated according to the similarity matrix", object$Z, "\n", fill=TRUE)
+  }
+
   cat("Alpha diversity of communities:", "\n")
   print(object$CommunityAlphaDiversities)
   cat("Total alpha diversity of the communities:", "\n")
